.. pyrs-resource documentation master file, created by
   sphinx-quickstart on Sun Aug 16 11:41:40 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents:
---------

.. toctree::
   :maxdepth: 2

   application
   resource
   request
   response
   errors
   hooks
   conf

License
-------

.. include:: ../LICENSE
   :literal:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

